==> tekton-model-triggers-v1alpha1-6.6.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/ClusterTriggerBindingListFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ClusterTriggerBindingListFluent<A extends ClusterTriggerBindingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,ClusterTriggerBinding item);
  public A setToItems(Integer index,ClusterTriggerBinding item);
  public A addToItems(io.fabric8.tekton.triggers.v1alpha1.ClusterTriggerBinding... items);
  public A addAllToItems(Collection<ClusterTriggerBinding> items);
  public A removeFromItems(io.fabric8.tekton.triggers.v1alpha1.ClusterTriggerBinding... items);
  public A removeAllFromItems(Collection<ClusterTriggerBinding> items);
  public A removeMatchingFromItems(Predicate<ClusterTriggerBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterTriggerBinding> getItems();
  public List<ClusterTriggerBinding> buildItems();
  public ClusterTriggerBinding buildItem(Integer index);
  public ClusterTriggerBinding buildFirstItem();
  public ClusterTriggerBinding buildLastItem();
  public ClusterTriggerBinding buildMatchingItem(Predicate<ClusterTriggerBindingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ClusterTriggerBindingBuilder> predicate);
  public A withItems(List<ClusterTriggerBinding> items);
  public A withItems(io.fabric8.tekton.triggers.v1alpha1.ClusterTriggerBinding... items);
  public Boolean hasItems();
  public ClusterTriggerBindingListFluent.ItemsNested<A> addNewItem();
  public ClusterTriggerBindingListFluent.ItemsNested<A> addNewItemLike(ClusterTriggerBinding item);
  public ClusterTriggerBindingListFluent.ItemsNested<A> setNewItemLike(Integer index,ClusterTriggerBinding item);
  public ClusterTriggerBindingListFluent.ItemsNested<A> editItem(Integer index);
  public ClusterTriggerBindingListFluent.ItemsNested<A> editFirstItem();
  public ClusterTriggerBindingListFluent.ItemsNested<A> editLastItem();
  public ClusterTriggerBindingListFluent.ItemsNested<A> editMatchingItem(Predicate<ClusterTriggerBindingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ClusterTriggerBindingFluent<ClusterTriggerBindingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/ClusterTriggerBindingListFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ClusterTriggerBindingListFluent<A extends ClusterTriggerBindingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,ClusterTriggerBinding item);
  public A setToItems(int index,ClusterTriggerBinding item);
  public A addToItems(io.fabric8.tekton.triggers.v1alpha1.ClusterTriggerBinding... items);
  public A addAllToItems(Collection<ClusterTriggerBinding> items);
  public A removeFromItems(io.fabric8.tekton.triggers.v1alpha1.ClusterTriggerBinding... items);
  public A removeAllFromItems(Collection<ClusterTriggerBinding> items);
  public A removeMatchingFromItems(Predicate<ClusterTriggerBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterTriggerBinding> getItems();
  public List<ClusterTriggerBinding> buildItems();
  public ClusterTriggerBinding buildItem(int index);
  public ClusterTriggerBinding buildFirstItem();
  public ClusterTriggerBinding buildLastItem();
  public ClusterTriggerBinding buildMatchingItem(Predicate<ClusterTriggerBindingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ClusterTriggerBindingBuilder> predicate);
  public A withItems(List<ClusterTriggerBinding> items);
  public A withItems(io.fabric8.tekton.triggers.v1alpha1.ClusterTriggerBinding... items);
  public Boolean hasItems();
  public ClusterTriggerBindingListFluent.ItemsNested<A> addNewItem();
  public ClusterTriggerBindingListFluent.ItemsNested<A> addNewItemLike(ClusterTriggerBinding item);
  public ClusterTriggerBindingListFluent.ItemsNested<A> setNewItemLike(int index,ClusterTriggerBinding item);
  public ClusterTriggerBindingListFluent.ItemsNested<A> editItem(int index);
  public ClusterTriggerBindingListFluent.ItemsNested<A> editFirstItem();
  public ClusterTriggerBindingListFluent.ItemsNested<A> editLastItem();
  public ClusterTriggerBindingListFluent.ItemsNested<A> editMatchingItem(Predicate<ClusterTriggerBindingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ClusterTriggerBindingFluent<ClusterTriggerBindingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
